@@ -35,9 +35,8 @@
 #' increase when going down some given branch. Strong FWER control holds as 
 #' well if the argument is set to FALSE which is the default option. 
 #' @param mt.adj type of multiple testing correction to be used; 
-#' either \code{"SBH"} (Sparse Branch Hierarchical multiple adjustment), 
-#' \code{"dpBF"} (depth-wise Bonferroni multiple adjustment), or \code{"none"}
-#' (no adjusment). See the 'Details' section.
+#' either \code{"dpBF"} (depth-wise Bonferroni multiple adjustment) or \code{"none"}
+#' (no adjustment). See the 'Details' section.
 #' @param agg.method a character string naming an aggregation method which
 #' aggregates the p-values over the different data sets for a given cluster;
 #' either \code{"Tippett"} (Tippett's rule) or \code{"Stouffer"}
@@ -59,14 +58,11 @@
 #' \code{\link{cluster_positions}} as an input (argument \code{dendr}).
 #'
 #' The user can specify which hierarchical multiple testing adjustment for the 
-#' hierarchical procedure is applied. The default is \code{mt.adj = "SBH"} 
-#' (Sparse Branch Hierarchical multiple adjustment), which is an improvement 
-#' over so-called depth-wise Bonferroni with respect to power. 
-#' Alternatively, the user can choose \code{"dpBF"} (depth-wise Bonferroni multiple 
-#' adjustment) or \code{"none"} (no adjustment). The hierarchical multiple testing
-#' adjustments \code{"SBH"} and \code{"dpBF"} guarantee strong family-wise error 
-#' control if the group test, which is applied for testing a given group, 
-#' controls the type I error. 
+#' hierarchical procedure is applied. The default is \code{"dpBF"} (depth-wise 
+#' Bonferroni multiple adjustment). Alternatively, the user can choose \code{"none"} 
+#' (no adjustment). The hierarchical multiple testing adjustment \code{"dpBF"} 
+#' guarantees strong family-wise error control if the group test, which is applied 
+#' for testing a given group, controls the type I error. 
 #' 
 #' The group test function has to be specified by the user; see argument 
 #' \code{test.func}. It is required to have the following 
@@ -186,8 +182,12 @@
 #' # Column names or variable names of the significant cluster in the first row.
 #' sign.clusters2[[1, "significant.cluster"]]
 #' 
-#' @references Renaux, C., Bühlmann, P. (2021), Efficient Multiple Testing 
-#' Adjustment for Hierarchical Inference. <arXiv:2104.15028> 
+#' @references 
+#' Meinshausen, N. (2008). Hierarchical testing of variable importance. 
+#' Biometrika, 95(2), 265-278.
+#' Renaux, C., Buzdugan, L., Kalisch, M., and Bühlmann, P. (2020). Hierarchical inference for 
+#' genome-wide association studies: a view on methodology with software. 
+#' Computational Statistics, 35(1), 1-40.
 #'
 #' @name run_hierarchy
 #' @export
@@ -201,7 +201,7 @@ run_hierarchy <- function(x, y, dendr, test.func,
                           alpha = 0.05, global.test = TRUE,
 
                           hier.adj = FALSE,
-                          mt.adj = c("SBH", "depth.Bonferroni", "none"), 
+                          mt.adj = c("dpBF", "none"), # "SBH"
                           agg.method = c("Tippett", "Stouffer"),
 
                           verbose = FALSE, sort.parallel = TRUE,
